==> estateplat-common-1.2.4-20210317.030413-668-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjCbjyqCbf.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
/**
 * @author <a href="mailto:jiangganzhi@gtmap.cn">jiangganzhi</a>
 * @version V1.0, 2021/3/16
 * @description 土地承包经营权承包方
 */
@Table(name = "DJSJ_CBJYQ_CBF")
public class DjsjCbjyqCbf {
    @Id
    private String cbzd_cbf_index;
    private String cbfmc;
    private String lxdh;
    private String cbfzjlx;
    private String cbfzjhm;
    private String cbhtbh;
    private Integer cbdkzs;

    public String getCbzd_cbf_index() {
        return cbzd_cbf_index;
    }

    public void setCbzd_cbf_index(String cbzd_cbf_index) {
        this.cbzd_cbf_index = cbzd_cbf_index;
    }

    public String getCbfmc() {
        return cbfmc;
    }

    public void setCbfmc(String cbfmc) {
        this.cbfmc = cbfmc;
    }

    public String getLxdh() {
        return lxdh;
    }

    public void setLxdh(String lxdh) {
        this.lxdh = lxdh;
    }

    public String getCbfzjlx() {
        return cbfzjlx;
    }

    public void setCbfzjlx(String cbfzjlx) {
        this.cbfzjlx = cbfzjlx;
    }

    public String getCbfzjhm() {
        return cbfzjhm;
    }

    public void setCbfzjhm(String cbfzjhm) {
        this.cbfzjhm = cbfzjhm;
    }

    public String getCbhtbh() {
        return cbhtbh;
    }

    public void setCbhtbh(String cbhtbh) {
        this.cbhtbh = cbhtbh;
    }

    public Integer getCbdkzs() {
        return cbdkzs;
    }

    public void setCbdkzs(Integer cbdkzs) {
        this.cbdkzs = cbdkzs;
    }
}

==> estateplat-common-1.2.4-20220701.080935-1064-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjCbjyqCbf.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
/**
 * @author <a href="mailto:jiangganzhi@gtmap.cn">jiangganzhi</a>
 * @version V1.0, 2021/3/16
 * @description 土地承包经营权承包方
 */
@Table(name = "DJSJ_CBJYQ_CBF")
public class DjsjCbjyqCbf {
    @Id
    private String cbzd_cbf_index;
    private String cbfmc;
    private String lxdh;
    private String cbfzjlx;
    private String cbfzjhm;
    private String cbhtbh;
    private Integer cbdkzs;
    private String bdcdyh;
    private String djh;

    public String getCbzd_cbf_index() {
        return cbzd_cbf_index;
    }

    public void setCbzd_cbf_index(String cbzd_cbf_index) {
        this.cbzd_cbf_index = cbzd_cbf_index;
    }

    public String getCbfmc() {
        return cbfmc;
    }

    public void setCbfmc(String cbfmc) {
        this.cbfmc = cbfmc;
    }

    public String getLxdh() {
        return lxdh;
    }

    public void setLxdh(String lxdh) {
        this.lxdh = lxdh;
    }

    public String getCbfzjlx() {
        return cbfzjlx;
    }

    public void setCbfzjlx(String cbfzjlx) {
        this.cbfzjlx = cbfzjlx;
    }

    public String getCbfzjhm() {
        return cbfzjhm;
    }

    public void setCbfzjhm(String cbfzjhm) {
        this.cbfzjhm = cbfzjhm;
    }

    public String getCbhtbh() {
        return cbhtbh;
    }

    public void setCbhtbh(String cbhtbh) {
        this.cbhtbh = cbhtbh;
    }

    public Integer getCbdkzs() {
        return cbdkzs;
    }

    public void setCbdkzs(Integer cbdkzs) {
        this.cbdkzs = cbdkzs;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }
}
